Module opcode2

Module opcode2 

Structs

Recv
Receive a message from a socket, equivalent to recv(2).
Send
Send a message on a socket, equivalent to send(2).
SendZc
Send a zerocopy message on a socket, equivalent to send(2).