Send

Struct Send 

pub struct Send<'a> { /* private fields */ }
Send a message on a socket, equivalent to send(2).

Implementations

Source

impl<'a> Send<'a>

pub const CODE: u8

pub fn new(entry: &'a mut Entry) -> Self

pub fn with(entry: &'a mut Entry, fd: impl UseFixed) -> Self

pub fn ioprio(self, ioprio: u16) -> Self

pub fn flags(self, flags: i32) -> Self

Source

impl<'a> Send<'a>

pub fn buffer(self, buf: *const u8, len: u32) -> Self

pub fn dest_addr(self, addr: *const sockaddr, len: socklen_t) -> Self

Set the destination address, for sending from an unconnected socket.

When set, dest_addr_len must be set as well. See also man 3 io_uring_prep_send_set_addr.