pub struct SendZc<'a> { /* private fields */ }Expand description
Send a zerocopy message on a socket, equivalent to send(2).
When dest_addr is non-zero it points to the address of the target with dest_addr_len
specifying its size, turning the request into a sendto(2)
A fixed (pre-mapped) buffer can optionally be used from pre-mapped buffers that have been
previously registered with Submitter::register_buffers.
This operation might result in two completion queue entries.
See the IORING_OP_SEND_ZC section at io_uring_enter for the exact semantics.
Notifications posted by this operation can be checked with notif.
Implementations
Sourceimpl<'a> SendZc<'a>
impl<'a> SendZc<'a>
pub fn buffer(self, buf: *const u8, len: u32) -> Self
Sourcepub fn buf_index(self, idx: u16) -> Self
pub fn buf_index(self, idx: u16) -> Self
The buf_index is an index into an array of fixed buffers, and is only valid if fixed
buffers were registered.
The buf and len arguments must fall within a region specified by buf_index in the previously registered buffer. The buffer need not be aligned with the start of the registered buffer.